@@ -453,7 +453,10 @@ void KViewPart::slotSetFullPage(bool fullpage)
     kdError(4300) << "KViewPart::slotSetFullPage() called without existing multipage" << endl;
 
   if (fullpage == false)
+  {
     slotShowSidebar();
+    multiPage->slotShowScrollbars(scrollbarHandling->isChecked());
+  }
 }
 
 
@@ -958,6 +961,8 @@ void KViewPart::setZoomValue(const QString &sval)
   _zoomVal.setZoomValue(sval);
   if (fval != _zoomVal.value())
     _zoomVal.setZoomValue(multiPage->setZoom(_zoomVal.value()));
+
+  mainWidget->setFocus(); 
 }
 
 
@@ -1179,7 +1184,7 @@ void KViewPart::setStatusBarTextFromMultiPage( const QString &msg )
 KAboutData* KViewPart::createAboutData()
 {
   return new KAboutData("kviewerpart", I18N_NOOP("Document Viewer Part"),
-                        "0.4", I18N_NOOP(""),
+                        "0.4.1", I18N_NOOP(""),
                         KAboutData::License_GPL,
                         I18N_NOOP("Copyright (c) 2005 Wilfried Huss"));
 }
@@ -1191,7 +1196,7 @@ void KViewPart::aboutKViewShell()
     // Create Dialog
     aboutDialog = new KAboutDialog(multiPage->scrollView(), "about_kviewshell");
     aboutDialog->setTitle(I18N_NOOP("KViewShell"));
-    aboutDialog->setVersion("0.4");
+    aboutDialog->setVersion("0.4.1");
     aboutDialog->setAuthor("Matthias Hoelzer-Kluepfel", QString::null, QString::null,
                            I18N_NOOP("Original Author"));
 
